===========
Application
===========

Module: :mod:`jupyterlab_server.app`
====================================

.. automodule:: jupyterlab_server.app

.. currentmodule:: jupyterlab_server.app

:class:`LabServerApp`
---------------------

.. autoconfigurable:: LabServerApp
